@@ -30,25 +30,32 @@ class Server(object):
                        The first async mode that has all its dependencies
                        installed is then one that is chosen.
     :param ping_timeout: The time in seconds that the client waits for the
-                         server to respond before disconnecting.
+                         server to respond before disconnecting. The default
+                         is 60 seconds.
     :param ping_interval: The interval in seconds at which the client pings
-                          the server.
+                          the server. The default is 25 seconds.
     :param max_http_buffer_size: The maximum size of a message when using the
-                                 polling transport.
-    :param allow_upgrades: Whether to allow transport upgrades or not.
+                                 polling transport. The default is 100,000,000
+                                 bytes.
+    :param allow_upgrades: Whether to allow transport upgrades or not. The
+                           default is ``True``.
     :param http_compression: Whether to compress packages when using the
-                             polling transport.
+                             polling transport. The default is ``True``.
     :param compression_threshold: Only compress messages when their byte size
-                                  is greater than this value.
+                                  is greater than this value. The default is
+                                  1024 bytes.
     :param cookie: Name of the HTTP cookie that contains the client session
                    id. If set to ``None``, a cookie is not sent to the client.
+                   The default is ``'io'``.
     :param cors_allowed_origins: List of origins that are allowed to connect
                                  to this server. All origins are allowed by
                                  default.
     :param cors_credentials: Whether credentials (cookies, authentication) are
-                             allowed in requests to this server.
+                             allowed in requests to this server. The default
+                             is ``True``.
     :param logger: To enable logging set to ``True`` or pass a logger object to
-                   use. To disable logging set to ``False``.
+                   use. To disable logging set to ``False``. The default is
+                   ``False``.
     :param json: An alternative json module to use for encoding and decoding
                  packets. Custom json modules must have ``dumps`` and ``loads``
                  functions that are compatible with the standard library
@@ -199,8 +206,14 @@ class Server(object):
                     is not given, then all clients are closed.
         """
         if sid is not None:
-            self._get_socket(sid).close()
-            del self.sockets[sid]
+            try:
+                socket = self._get_socket(sid)
+            except KeyError:  # pragma: no cover
+                # the socket was already closed or gone
+                pass
+            else:
+                socket.close()
+                del self.sockets[sid]
         else:
             for client in six.itervalues(self.sockets):
                 client.close()
@@ -282,12 +295,11 @@ class Server(object):
                         if sid in self.sockets:  # pragma: no cover
                             self.disconnect(sid)
                         r = self._bad_request()
-                    except Exception as e:
-                        # for any other unexpected errors, we disconnect
-                        # the cient and reraise
-                        if sid in self.sockets:  # pragma: no cover
-                            self.disconnect(sid)
-                        raise e
+                    except:  # pragma: no cover
+                        # for any other unexpected errors, we log the error
+                        # and keep going
+                        self.logger.exception('post request handler error')
+                        r = self._ok()
             else:
                 self.logger.warning('Method %s not supported', method)
                 r = self._method_not_found()
@@ -355,19 +367,10 @@ class Server(object):
                           'pingInterval': int(self.ping_interval * 1000)})
         s.send(pkt)
 
-        reraise_exc = None
-        try:
-            ret = self._trigger_event('connect', sid, environ, async=False)
-        except Exception as e:
-            ret = False
-            reraise_exc = e
+        ret = self._trigger_event('connect', sid, environ, run_async=False)
         if ret is False:
             del self.sockets[sid]
-            if reraise_exc is None:
-                self.logger.warning('Application rejected connection')
-            else:
-                self.logger.error('Connect handler raised an exception')
-                raise reraise_exc
+            self.logger.warning('Application rejected connection')
             return self._unauthorized()
 
         if transport == 'websocket':
@@ -393,12 +396,19 @@ class Server(object):
 
     def _trigger_event(self, event, *args, **kwargs):
         """Invoke an event handler."""
-        async = kwargs.pop('async', False)
+        run_async = kwargs.pop('run_async', False)
         if event in self.handlers:
-            if async:
+            if run_async:
                 return self.start_background_task(self.handlers[event], *args)
             else:
-                return self.handlers[event](*args)
+                try:
+                    return self.handlers[event](*args)
+                except:
+                    self.logger.exception(event + ' handler error')
+                    if event == 'connect':
+                        # if connect handler raised error we reject the
+                        # connection
+                        return False
 
     def _get_socket(self, sid):
         """Return the socket object for a given session."""
